# Project Description

# Release History


## version==0.03
将所有公共 models 维护至本项目。
需要以下环境变量:  
```
SPARROW_ORDER_APP_LABEL
SPARROW_DISTRIBUTE_APP_LABEL  
SPARROW_AFTERSALE_APP_LABEL
SPARROW_EXCHANGE_APP_LABEL
SPARROW_PROMOTIONS_APP_LABEL
```

settings 要包含以下配置
```
PHONE_NUMBER_REGEX
```

## version==0.02
测试 models 维护至 sparrow-order-lib 可行性

## version==0.01
core.db_tool.query
